% find expected values of both offers for each trial
% EV1 = expected values for first shown offer
% EV2 = expected values for second shown offer
function [EV1, EV2] = expectedValues(cellData)
% find expected value of both offers for each trial
    vars = cellData.vars;
    number_of_trials = size(cellData.psth,1);
    EV1 = zeros(number_of_trials,1);
    EV2 = zeros(number_of_trials,1);
    
    % determine which offer came first. 1: left, 2: right
    firstOffer = vars(:,15);
    % determine values necessary to calculate EV (reward values and
    % probabilities)
    leftTop = vars(:,5);
    leftBottom = vars(:,6);
    leftTopProb = vars(:,12);
    rightTop = vars(:,7);
    rightBottom = vars(:,8);
    rightTopProb = vars(:,13);
    
    leftTopProb = leftTopProb./100;
    rightTopProb = rightTopProb./100;
    
    leftFirst = find(firstOffer==1);
    rightFirst = find(firstOffer==2);
    
    EV1(leftFirst) = (leftTopProb(leftFirst).*leftTop(leftFirst)) + ((1-leftTopProb(leftFirst)).*leftBottom(leftFirst));
    % (if left isn't first, right must be first)
    EV1(rightFirst) = (rightTopProb(rightFirst).*rightTop(rightFirst)) + ((1-rightTopProb(rightFirst)).*rightBottom(rightFirst));
    % (if left is first, right must be second)
    EV2(leftFirst) = (rightTopProb(leftFirst).*rightTop(leftFirst)) + ((1-rightTopProb(leftFirst)).*rightBottom(leftFirst));
    % (if left isn't first, left must be second)
    EV2(rightFirst) = (leftTopProb(rightFirst).*leftTop(rightFirst)) + ((1-leftTopProb(rightFirst)).*leftBottom(rightFirst));
end